@@ -20,7 +20,7 @@
 #' @export
 #' @keywords internal
 new_geodesic_path <- function(name, generator, frozen = NULL, ...) {
-  tries <- 1
+  tries <- 1 # Needed for guided
 
   tour_path <- function(current, data, ...) {
     if (is.null(current)) {
@@ -46,7 +46,7 @@ new_geodesic_path <- function(name, generator, frozen = NULL, ...) {
         return(NULL)
       }
 
-      cat("generation:  dist =  ", dist, "\n")
+      #cat("generation:  dist =  ", dist, "\n")
     }
     list(ingred = geodesic_path(current, target, frozen, ...), index = gen$index, tries = tries)
   }
