@@ -8,18 +8,19 @@
 #' \code{\link{save_history}} or \code{\link{render}}.
 #'
 #' @param start initial projection matrix
-#' @param mvar variable chosen to rotate out
+#' @param mvar variable(s) chosen to rotate out
 #' @param ... additional arguments for drawing
 #' @export
 #' @examples
 #' animate_xy(flea[, 1:6], radial_tour(basis_random(6, 2), mvar = 4))
+#' animate_xy(flea[, 1:6], radial_tour(basis_random(6, 2), mvar = c(3,4)))
 #' animate_dist(flea[, 1:6], radial_tour(basis_random(6, 1), mvar = 4))
 #' animate_scatmat(flea[, 1:6], radial_tour(basis_random(6, 3), mvar = 4))
 radial_tour <- function(start, mvar = 1, ...) {
   first <- TRUE
   out <- TRUE
 
-  generator <- function(current, data, mvar, ...) {
+  generator <- function(current, data, ...) {
     if (first) {
       new_basis <- start
       first <<- FALSE
